==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosRuleFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosRuleFluent<A extends PodHttpChaosRuleFluent<A>> extends BaseFluent<A>{
  public PodHttpChaosRuleFluent() {
  }
  public PodHttpChaosRuleFluent(PodHttpChaosRule instance) {
    instance = (instance != null ? instance : new PodHttpChaosRule());

    if (instance != null) {
      this.withActions(instance.getActions());
      this.withPort(instance.getPort());
      this.withSelector(instance.getSelector());
      this.withSource(instance.getSource());
      this.withTarget(instance.getTarget());
      this.withActions(instance.getActions());
      this.withPort(instance.getPort());
      this.withSelector(instance.getSelector());
      this.withSource(instance.getSource());
      this.withTarget(instance.getTarget());
    }
  }
  private PodHttpChaosActionsBuilder actions;
  private Integer port;
  private PodHttpChaosSelectorBuilder selector;
  private String source;
  private String target;
  public PodHttpChaosActions buildActions() {
    return this.actions!=null ?this.actions.build():null;
  }
  public A withActions(PodHttpChaosActions actions) {
    _visitables.get("actions").remove(this.actions);
    if (actions!=null){ this.actions= new PodHttpChaosActionsBuilder(actions); _visitables.get("actions").add(this.actions);} else { this.actions = null; _visitables.get("actions").remove(this.actions); } return (A) this;
  }
  public boolean hasActions() {
    return this.actions != null;
  }
  public ActionsNested<A> withNewActions() {
    return new ActionsNested(null);
  }
  public ActionsNested<A> withNewActionsLike(PodHttpChaosActions item) {
    return new ActionsNested(item);
  }
  public ActionsNested<A> editActions() {
    return withNewActionsLike(java.util.Optional.ofNullable(buildActions()).orElse(null));
  }
  public ActionsNested<A> editOrNewActions() {
    return withNewActionsLike(java.util.Optional.ofNullable(buildActions()).orElse(new PodHttpChaosActionsBuilder().build()));
  }
  public ActionsNested<A> editOrNewActionsLike(PodHttpChaosActions item) {
    return withNewActionsLike(java.util.Optional.ofNullable(buildActions()).orElse(item));
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public boolean hasPort() {
    return this.port != null;
  }
  public PodHttpChaosSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(PodHttpChaosSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new PodHttpChaosSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public boolean hasSelector() {
    return this.selector != null;
  }
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  public SelectorNested<A> withNewSelectorLike(PodHttpChaosSelector item) {
    return new SelectorNested(item);
  }
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodHttpChaosSelectorBuilder().build()));
  }
  public SelectorNested<A> editOrNewSelectorLike(PodHttpChaosSelector item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public boolean hasSource() {
    return this.source != null;
  }
  public String getTarget() {
    return this.target;
  }
  public A withTarget(String target) {
    this.target=target; return (A) this;
  }
  public boolean hasTarget() {
    return this.target != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosRuleFluent that = (PodHttpChaosRuleFluent) o;
    if (!java.util.Objects.equals(actions, that.actions)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    if (!java.util.Objects.equals(selector, that.selector)) return false;

    if (!java.util.Objects.equals(source, that.source)) return false;

    if (!java.util.Objects.equals(target, that.target)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(actions,  port,  selector,  source,  target,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (actions != null) { sb.append("actions:"); sb.append(actions + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (target != null) { sb.append("target:"); sb.append(target); }
    sb.append("}");
    return sb.toString();
  }
  public class ActionsNested<N> extends PodHttpChaosActionsFluent<ActionsNested<N>> implements Nested<N>{
    ActionsNested(PodHttpChaosActions item) {
      this.builder = new PodHttpChaosActionsBuilder(this, item);
    }
    PodHttpChaosActionsBuilder builder;
    public N and() {
      return (N) PodHttpChaosRuleFluent.this.withActions(builder.build());
    }
    public N endActions() {
      return and();
    }
    
  }
  public class SelectorNested<N> extends PodHttpChaosSelectorFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodHttpChaosSelector item) {
      this.builder = new PodHttpChaosSelectorBuilder(this, item);
    }
    PodHttpChaosSelectorBuilder builder;
    public N and() {
      return (N) PodHttpChaosRuleFluent.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosRuleFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PodHttpChaosRuleFluent<A extends PodHttpChaosRuleFluent<A>> extends BaseFluent<A>{
  public PodHttpChaosRuleFluent() {
  }
  
  public PodHttpChaosRuleFluent(PodHttpChaosRule instance) {
    this.copyInstance(instance);
  }
  private PodHttpChaosActionsBuilder actions;
  private Integer port;
  private PodHttpChaosSelectorBuilder selector;
  private String source;
  private String target;
  
  protected void copyInstance(PodHttpChaosRule instance) {
    instance = (instance != null ? instance : new PodHttpChaosRule());
  
    if (instance != null) {
        this.withActions(instance.getActions());
        this.withPort(instance.getPort());
        this.withSelector(instance.getSelector());
        this.withSource(instance.getSource());
        this.withTarget(instance.getTarget());
        this.withActions(instance.getActions());
        this.withPort(instance.getPort());
        this.withSelector(instance.getSelector());
        this.withSource(instance.getSource());
        this.withTarget(instance.getTarget());
      }
  }
  
  public PodHttpChaosActions buildActions() {
    return this.actions!=null ?this.actions.build():null;
  }
  
  public A withActions(PodHttpChaosActions actions) {
    _visitables.get("actions").remove(this.actions);
    if (actions!=null){ this.actions= new PodHttpChaosActionsBuilder(actions); _visitables.get("actions").add(this.actions);} else { this.actions = null; _visitables.get("actions").remove(this.actions); } return (A) this;
  }
  
  public boolean hasActions() {
    return this.actions != null;
  }
  
  public ActionsNested<A> withNewActions() {
    return new ActionsNested(null);
  }
  
  public ActionsNested<A> withNewActionsLike(PodHttpChaosActions item) {
    return new ActionsNested(item);
  }
  
  public ActionsNested<A> editActions() {
    return withNewActionsLike(java.util.Optional.ofNullable(buildActions()).orElse(null));
  }
  
  public ActionsNested<A> editOrNewActions() {
    return withNewActionsLike(java.util.Optional.ofNullable(buildActions()).orElse(new PodHttpChaosActionsBuilder().build()));
  }
  
  public ActionsNested<A> editOrNewActionsLike(PodHttpChaosActions item) {
    return withNewActionsLike(java.util.Optional.ofNullable(buildActions()).orElse(item));
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public PodHttpChaosSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  
  public A withSelector(PodHttpChaosSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new PodHttpChaosSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  
  public boolean hasSelector() {
    return this.selector != null;
  }
  
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  
  public SelectorNested<A> withNewSelectorLike(PodHttpChaosSelector item) {
    return new SelectorNested(item);
  }
  
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodHttpChaosSelectorBuilder().build()));
  }
  
  public SelectorNested<A> editOrNewSelectorLike(PodHttpChaosSelector item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  
  public String getSource() {
    return this.source;
  }
  
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  
  public boolean hasSource() {
    return this.source != null;
  }
  
  public String getTarget() {
    return this.target;
  }
  
  public A withTarget(String target) {
    this.target=target; return (A) this;
  }
  
  public boolean hasTarget() {
    return this.target != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosRuleFluent that = (PodHttpChaosRuleFluent) o;
    if (!java.util.Objects.equals(actions, that.actions)) return false;
  
    if (!java.util.Objects.equals(port, that.port)) return false;
  
    if (!java.util.Objects.equals(selector, that.selector)) return false;
  
    if (!java.util.Objects.equals(source, that.source)) return false;
  
    if (!java.util.Objects.equals(target, that.target)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(actions,  port,  selector,  source,  target,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (actions != null) { sb.append("actions:"); sb.append(actions + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (target != null) { sb.append("target:"); sb.append(target); }
    sb.append("}");
    return sb.toString();
  }
  public class ActionsNested<N> extends PodHttpChaosActionsFluent<ActionsNested<N>> implements Nested<N>{
    ActionsNested(PodHttpChaosActions item) {
      this.builder = new PodHttpChaosActionsBuilder(this, item);
    }
    PodHttpChaosActionsBuilder builder;
    
    public N and() {
      return (N) PodHttpChaosRuleFluent.this.withActions(builder.build());
    }
    
    public N endActions() {
      return and();
    }
    
  
  }
  public class SelectorNested<N> extends PodHttpChaosSelectorFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodHttpChaosSelector item) {
      this.builder = new PodHttpChaosSelectorBuilder(this, item);
    }
    PodHttpChaosSelectorBuilder builder;
    
    public N and() {
      return (N) PodHttpChaosRuleFluent.this.withSelector(builder.build());
    }
    
    public N endSelector() {
      return and();
    }
    
  
  }

}
